from cx4.cxscheduler cimport sl_main_loop, sl_break, sl_at_select_proc, sl_set_select_behaviour
cimport cx4.cxscheduler as sl

cpdef main_loop():
    sl_main_loop()

cpdef break_():
    sl_break()


# some deprecated code to
# def select_interrupt_action():
#     pass
#
# cdef void at_select() with gil:
#     select_interrupt_action()
#
# sl_set_select_behaviour(<sl_at_select_proc>NULL, <sl_at_select_proc>at_select, 100000)

SL_RD = sl.SL_RD
SL_WR = sl.SL_WR
SL_EX = sl.SL_EX
SL_CE = sl.SL_CE




from cx4.cxscheduler cimport sl_add_fd, sl_del_fd, sl_fdh_t

cdef void fd_event_proc(int uniq, void *privptr1, sl_fdh_t fdh, int fd, int mask, void *privptr2) with gil:
    cdef FdEvent fev = <FdEvent>privptr1
    fev.ready.emit(fev)


cdef class FdEvent:
    cdef readonly:
        object file, ready
        int mask
        sl_fdh_t fhd

    def __cinit__(self, file, mask=SL_RD):
        self.file = file
        self.mask = mask
        self.ready = Signal(object)
        self.fhd = sl_add_fd(0, <void*>self, file.fileno(), mask, fd_event_proc, NULL)

    def __dealloc__(self):
        sl_del_fd(self.fhd)
